Learn R Programming

DRIMSeq (version 1.0.2)

dmSQTLfit-class: dmSQTLfit object

Description

dmSQTLfit extends the dmDSdispersion class by adding the full model Dirichlet-multinomial feature proportion estimates needed for the sQTL analysis. Feature ratios are estimated for each gene and each group that is defined by different SNPs/blocks. Result of dmFit.

Arguments

Slots

dispersion
Character specifying which type of dispersion was used for fitting: "common_dispersion" or "genewise_dispersion".
fit_full
List of MatrixList objects. Each element of this list contains the full model proportion estimates for all the blocks associated with a given gene. Columns of MatrixLists correspond to 3 genotypes (0,1,2). The full model likelihoods are stored in metadata slot.

See Also

data_dmSQTLdata, dmSQTLdata, dmSQTLdispersion, dmSQTLtest